Learn R Programming

mumarinex (version 1.0)

diagnostic_tool: Diagnostic tool to identify the key components that best explain the MUMARINEX sub-indices

Description

Identifies, for each sub-index, the species or taxa that contribute most to its variation.

Usage

diagnostic_tool(x, g, ref, signif_test = TRUE, mute = FALSE)

Value

A data frame summarizing the key information explaining variations in CSR, CBCD, and CPI.

Arguments

x

A data frame or a matrix organized with samples in rows and species in columns.

g

A vector of length nrow(x) indicating how the samples should be grouped (e.g., stations, treatments).

ref

A logical or numeric vector identifying the reference row positions.

signif_test

Logical; if TRUE, only sub-indices significantly lower than the reference conditions (t-test, p < 0.05) are returned. Conditions that are not statistically significant are indicated by 'ns'.

mute

A logical indicating whether the results are displayed in the console.

Details

diagnostic_tool

See Also

decomplot()

Examples

Run this code
data("Simulated_data")
ref_idx<-41:50
stations<-matrix(unlist(strsplit(rownames(Simulated_data),".",fixed=TRUE)),ncol=2,byrow=TRUE)[,1]
diagnostic_tool(x=Simulated_data,g=stations,ref=ref_idx)

Run the code above in your browser using DataLab