A data frame summarizing the key information explaining variations in CSR, CBCD, and CPI.
Arguments
x
A data frame or a matrix organized with samples in rows and species in columns.
g
A vector of length nrow(x) indicating how the samples should be grouped (e.g., stations, treatments).
ref
A logical or numeric vector identifying the reference row positions.
signif_test
Logical; if TRUE, only sub-indices significantly lower than the reference conditions (t-test, p < 0.05) are returned. Conditions that are not statistically significant are indicated by 'ns'.
mute
A logical indicating whether the results are displayed in the console.